@@ -6,10 +6,10 @@ from __future__ import absolute_import
 import logging
 log = logging.getLogger(__name__)
 
-import calendar
 import datetime as dt
 import decimal
 import json
+import time
 
 import numpy as np
 
@@ -38,13 +38,15 @@ class BokehJSONEncoder(json.JSONEncoder):
             return int(obj)
         elif np.issubdtype(type(obj), np.bool_):
             return bool(obj)
-        # Datetime
-        # datetime is a subclass of date.
+        # Datetime (datetime is a subclass of date)
         elif isinstance(obj, dt.datetime):
-            return calendar.timegm(obj.timetuple()) * 1000. + obj.microsecond / 1000.
+            return time.mktime(obj.timetuple()) * 1000. + obj.microsecond / 1000.
+        # Timedelta (timedelta is class in the datetime library)
+        elif isinstance(obj, dt.timedelta):
+            return obj.total_seconds() * 1000.
         # Date
         elif isinstance(obj, dt.date):
-            return calendar.timegm(obj.timetuple()) * 1000.
+            return time.mktime(obj.timetuple()) * 1000.
         # Numpy datetime64
         elif isinstance(obj, np.datetime64):
             epoch_delta = obj - np.datetime64('1970-01-01T00:00:00Z')
