@@ -3,7 +3,9 @@ from __future__ import absolute_import, print_function
 import logging
 logger = logging.getLogger(__file__)
 
+from contextlib import contextmanager
 from json import loads
+from operator import itemgetter
 
 from six import iteritems
 
@@ -15,6 +17,7 @@ from .util.callback_manager import CallbackManager
 from .util.future import with_metaclass
 from .util.serialization import make_id
 
+
 class Viewable(MetaHasProps):
     """ Any plot object (Data Model) which has its own View Model in the
     persistence layer.
@@ -87,8 +90,8 @@ class Model(with_metaclass(Viewable, HasProps, CallbackManager)):
         '''This should only be called by the Document implementation to set the document field'''
         if self._document is not None and self._document is not doc:
             raise RuntimeError("Models must be owned by only a single document, %r is already in a doc" % (self))
-        self._document = doc
         doc.theme.apply_to_model(self)
+        self._document = doc
 
     def _detach_document(self):
         '''This should only be called by the Document implementation to unset the document field'''
@@ -100,14 +103,21 @@ class Model(with_metaclass(Viewable, HasProps, CallbackManager)):
         return self._document
 
     def trigger(self, attr, old, new, hint=None):
-        dirty = { 'count' : 0 }
-        def mark_dirty(obj):
-            dirty['count'] += 1
-        if self._document is not None:
-            self._visit_value_and_its_immediate_references(new, mark_dirty)
-            self._visit_value_and_its_immediate_references(old, mark_dirty)
-            if dirty['count'] > 0:
-                self._document._invalidate_all_models()
+        # The explicit assumption here is that hinted events do not
+        # need to go through all the same invalidation steps. Currently
+        # as of Bokeh 0.11.1 the only hinted event is ColumnsStreamedEvent.
+        # This may need to be further refined in the future, if the
+        # assumption does not hold for future hinted events (e.g. the hint
+        # could specify explicitly whether to do normal invalidation or not)
+        if not hint:
+            dirty = { 'count' : 0 }
+            def mark_dirty(obj):
+                dirty['count'] += 1
+            if self._document is not None:
+                self._visit_value_and_its_immediate_references(new, mark_dirty)
+                self._visit_value_and_its_immediate_references(old, mark_dirty)
+                if dirty['count'] > 0:
+                    self._document._invalidate_all_models()
         # chain up to invoke callbacks
         super(Model, self).trigger(attr, old, new, hint)
 
@@ -255,7 +265,21 @@ class Model(with_metaclass(Viewable, HasProps, CallbackManager)):
                 that haven't been changed from the default.
 
         """
-        attrs = self.properties_with_values(include_defaults=include_defaults)
+        all_attrs = self.properties_with_values(include_defaults=include_defaults)
+
+        # If __subtype__ is defined, then this model may introduce properties
+        # that don't exist on __view_model__ in bokehjs. Don't serialize such
+        # properties.
+        subtype = getattr(self.__class__, "__subtype__", None)
+        if subtype is not None and subtype != self.__class__.__view_model__:
+            attrs = {}
+            for attr, value in all_attrs.items():
+                if attr in self.__class__.__dict__:
+                    continue
+                else:
+                    attrs[attr] = value
+        else:
+            attrs = all_attrs
 
         for (k, v) in attrs.items():
             # we can't serialize Infinity, we send it as None and
@@ -320,8 +344,85 @@ class Model(with_metaclass(Viewable, HasProps, CallbackManager)):
         return serialize_json(json_like)
 
     def __str__(self):
-        return "%s, ViewModel:%s, ref _id: %s" % (self.__class__.__name__,
-                self.__view_model__, getattr(self, "_id", None))
+        return "%s(id=%r, ...)" % (self.__class__.__name__, getattr(self, "_id", None))
+
+    __repr__ = __str__
+
+    def _bokeh_repr_pretty_(self, p, cycle):
+        name = "%s.%s" % (self.__class__.__module__, self.__class__.__name__)
+        _id = getattr(self, "_id", None)
+
+        if cycle:
+            p.text(name)
+            p.text('(id=')
+            p.pretty(_id)
+            p.text(', ...)')
+        else:
+            with p.group(4, '%s(' % name, ')'):
+                props = self.properties_with_values().items()
+                sorted_props = sorted(props, key=itemgetter(0))
+                all_props = [('id', _id)] + sorted_props
+                for i, (prop, value) in enumerate(all_props):
+                    if i == 0:
+                        p.breakable('')
+                    else:
+                        p.text(',')
+                        p.breakable()
+                    p.text(prop)
+                    p.text('=')
+                    p.pretty(value)
+
+    def _repr_html_(self):
+        module = self.__class__.__module__
+        name = self.__class__.__name__
+
+        _id = getattr(self, "_id", None)
+
+        cls_name = make_id()
+
+        def row(c):
+            return '<div style="display: table-row;">' + c + '</div>'
+        def hidden_row(c):
+            return '<div class="%s" style="display: none;">%s</div>' % (cls_name, c)
+        def cell(c):
+            return '<div style="display: table-cell;">' + c + '</div>'
+
+        html = ''
+        html += '<div style="display: table;">'
+
+        ellipsis_id = make_id()
+        ellipsis = '<span id="%s" style="cursor: pointer;">&hellip;)</span>' % ellipsis_id
+
+        prefix = cell('<b title="%s.%s">%s</b>(' % (module, name, name))
+        html += row(prefix + cell('id' + '&nbsp;=&nbsp;' + repr(_id) + ', ' + ellipsis))
+
+        props = self.properties_with_values().items()
+        sorted_props = sorted(props, key=itemgetter(0))
+        all_props = sorted_props
+        for i, (prop, value) in enumerate(all_props):
+            end = ')' if i == len(all_props)-1 else ','
+            html += hidden_row(cell("") + cell(prop + '&nbsp;=&nbsp;' + repr(value) + end))
+
+        html += '</div>'
+        html += """
+<script>
+(function() {
+  var expanded = false;
+  var ellipsis = document.getElementById("%(ellipsis_id)s");
+  ellipsis.addEventListener("click", function() {
+    var rows = document.getElementsByClassName("%(cls_name)s");
+    for (var i = 0; i < rows.length; i++) {
+      var el = rows[i];
+      el.style.display = expanded ? "none" : "table-row";
+    }
+    ellipsis.innerHTML = expanded ? "&hellip;)" : "&lsaquo;&lsaquo;&lsaquo;";
+    expanded = !expanded;
+  });
+})();
+</script>
+""" % dict(ellipsis_id=ellipsis_id, cls_name=cls_name)
+
+        return html
 
 def _find_some_document(models):
     from .document import Document
@@ -379,3 +480,21 @@ class _ModelInDocument(object):
     def __enter__(self):
         for model in self._to_remove_after:
             self._doc.add_root(model)
+
+
+@contextmanager
+def _ModelInEmptyDocument(model):
+    from .document import Document
+    full_doc = _find_some_document([model])
+
+    model._document = None
+    for ref in model.references():
+        ref._document = None
+    empty_doc = Document()
+    empty_doc.add_root(model)
+
+    yield model
+
+    model._document = full_doc
+    for ref in model.references():
+        ref._document = full_doc
