@@ -5,28 +5,83 @@ types that Bokeh supports.
 from __future__ import absolute_import
 
 import logging
-
-from ..plot_object import PlotObject
-from ..properties import abstract
-from ..properties import String, Enum, Instance
-from ..enums import Units, RenderLevel
-from ..validation.errors import BAD_COLUMN_NAME, MISSING_GLYPH, NO_SOURCE_FOR_GLYPH
-from .. import validation
-
-from .sources import DataSource, RemoteSource
-from .glyphs import Glyph
-
 logger = logging.getLogger(__name__)
 
+from ..model import Model
+from ..core.enums import RenderLevel
+from ..core.properties import abstract
+from ..core.properties import String, Enum, Instance, Float, Bool, Override
+from ..core import validation
+from ..core.validation.errors import BAD_COLUMN_NAME, MISSING_GLYPH, NO_SOURCE_FOR_GLYPH
+
+from .glyphs import Glyph
+from .images import ImageSource
+from .sources import DataSource, RemoteSource
+from .tiles import TileSource, WMTSTileSource
 
 @abstract
-class Renderer(PlotObject):
-    """ A base class for renderer types. ``Renderer`` is not
-    generally useful to instantiate on its own.
-
+class Renderer(Model):
+    """An abstract base class for renderer types.
     """
 
-class GlyphRenderer(Renderer):
+    level = Enum(RenderLevel, help="""
+    Specifies the level in which to paint this renderer.
+    """)
+
+    visible = Bool(default=True, help="""
+    Is the renderer visible. Default: True
+    """)
+
+@abstract
+class DataRenderer(Renderer):
+    """ An abstract base class for data renderer types (e.g. ``GlyphRenderer``, ``TileRenderer``).
+    """
+
+class TileRenderer(DataRenderer):
+
+    tile_source = Instance(TileSource, default=lambda: WMTSTileSource(), help="""
+    Local data source to use when rendering glyphs on the plot.
+    """)
+
+    alpha = Float(1.0, help="""
+    tile opacity 0.0 - 1.0
+    """)
+
+    x_range_name = String('default', help="""
+    A particular (named) x-range to use for computing screen
+    locations when rendering glyphs on the plot. If unset, use the
+    default x-range.
+    """)
+
+    y_range_name = String('default', help="""
+    A particular (named) y-range to use for computing screen
+    locations when rendering glyphs on the plot. If unset, use the
+    default y-range.
+    """)
+
+    level = Override(default="underlay")
+
+    render_parents = Bool(default=True, help="""
+    Flag enable/disable drawing of parent tiles while waiting for new tiles to arrive. Default value is True.
+    """)
+
+class DynamicImageRenderer(DataRenderer):
+
+    image_source = Instance(ImageSource, help="""
+    Image source to use when rendering on the plot.
+    """)
+
+    alpha = Float(1.0, help="""
+    tile opacity 0.0 - 1.0
+    """)
+
+    level = Override(default="underlay")
+
+    render_parents = Bool(default=True, help="""
+    Flag enable/disable drawing of parent tiles while waiting for new tiles to arrive. Default value is True.
+    """)
+
+class GlyphRenderer(DataRenderer):
     """
 
     """
@@ -45,7 +100,9 @@ class GlyphRenderer(Renderer):
         if not self.data_source: return
         if isinstance(self.data_source, RemoteSource): return
         missing = set()
-        for name, item in self.glyph.vm_serialize().items():
+        specs = self.glyph.dataspecs()
+        for name, item in self.glyph.properties_with_values(include_defaults=False).items():
+            if name not in specs: continue
             if not isinstance(item, dict): continue
             if 'field' in item and item['field'] not in self.data_source.column_names:
                 missing.add(item['field'])
@@ -68,9 +125,6 @@ class GlyphRenderer(Renderer):
     default -range.
     """)
 
-    # TODO: (bev) is this actually used?
-    units = Enum(Units)
-
     glyph = Instance(Glyph, help="""
     The glyph to render, in conjunction with the supplied data source
     and ranges.
@@ -86,10 +140,13 @@ class GlyphRenderer(Renderer):
     but not when no points at all are selected.)
     """)
 
-    level = Enum(RenderLevel, default="glyph", help="""
-    Specifies the level in which to render the glyph.
+    hover_glyph = Instance(Glyph, help="""
+    An optional glyph used for inspected points, e.g., those that are
+    being hovered over by a HoverTool.
     """)
 
+    level = Override(default="glyph")
+
 @abstract
 class GuideRenderer(Renderer):
     """ A base class for all guide renderer types. ``GuideRenderer`` is
@@ -107,3 +164,5 @@ class GuideRenderer(Renderer):
         if self.plot is not None:
             if self not in self.plot.renderers:
                 self.plot.renderers.append(self)
+
+    level = Override(default="overlay")
