@@ -1,9 +1,11 @@
+'''
+
+'''
 from __future__ import absolute_import
 
-try:
-    import pandas as pd
-except ImportError as e:
-    raise RuntimeError("population data requires pandas (http://pandas.pydata.org) to be installed")
+from bokeh.util.dependencies import import_required
+pd = import_required('pandas',
+              'population sample data requires Pandas (http://pandas.pydata.org) to be installed')
 
 from . import _data_dir
 
