@@ -8,6 +8,7 @@ module.exports = {
   Label: require("../models/annotations/label").Model,
   LabelSet: require("../models/annotations/label_set").Model,
   Legend: require("../models/annotations/legend").Model,
+  LegendItem: require("../models/annotations/legend_item").Model,
   PolyAnnotation: require("../models/annotations/poly_annotation").Model,
   Span: require("../models/annotations/span").Model,
   Title: require("../models/annotations/title").Model,
@@ -50,7 +51,6 @@ module.exports = {
   Segment: require("../models/glyphs/segment").Model,
   Text: require("../models/glyphs/text").Model,
   Wedge: require("../models/glyphs/wedge").Model,
-  Gear: require("../models/glyphs/gear").Model,
   Grid: require("../models/grids/grid").Model,
   ImageSource: require("../models/tiles/image_source").Model,
   LayoutDOM: require("../models/layouts/layout_dom").Model,
@@ -60,7 +60,18 @@ module.exports = {
   WidgetBox: require("../models/layouts/widget_box").Model,
   GMapPlot: require("../models/plots/gmap_plot").Model,
   LinearColorMapper: require("../models/mappers/linear_color_mapper").Model,
-  markers: [require('../models/markers/index')],
+  Asterisk: require('../models/markers/index').Asterisk.Model,
+  CircleCross: require('../models/markers/index').CircleCross.Model,
+  CircleX: require('../models/markers/index').CircleX.Model,
+  Cross: require('../models/markers/index').Cross.Model,
+  Diamond: require('../models/markers/index').Diamond.Model,
+  DiamondCross: require('../models/markers/index').DiamondCross.Model,
+  InvertedTriangle: require('../models/markers/index').InvertedTriangle.Model,
+  Square: require('../models/markers/index').Square.Model,
+  SquareCross: require('../models/markers/index').SquareCross.Model,
+  SquareX: require('../models/markers/index').SquareX.Model,
+  Triangle: require('../models/markers/index').Triangle.Model,
+  X: require('../models/markers/index').X.Model,
   Model: require("../model").Model,
   Plot: require("../models/plots/plot").Model,
   Range: require("../models/ranges/range").Model,
@@ -98,7 +109,7 @@ module.exports = {
   ToolbarBase: require("../models/tools/toolbar_base").Model,
   Toolbar: require("../models/tools/toolbar").Model,
   ToolbarBox: require("../models/tools/toolbar_box").Model,
-  ToolEvents: require("../common/tool_events").Model,
+  ToolEvents: require("../models/tools/tool_events").Model,
   Tool: require("../models/tools/tool").Model,
   PanTool: require("../models/tools/gestures/pan_tool").Model,
   WheelZoomTool: require("../models/tools/gestures/wheel_zoom_tool").Model,
