@@ -1,7 +1,8 @@
 var $, BOKEH_ROOT, Document, Figure, _, _default_tools, _default_tooltips, _known_tools, _with_default, color, embed, figure, gridplot, models, show, sprintf,
   extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
   hasProp = {}.hasOwnProperty,
-  slice = [].slice;
+  slice = [].slice,
+  indexOf = [].indexOf || function(item) { for (var i = 0, l = this.length; i < l; i++) { if (i in this && this[i] === item) return i; } return -1; };
 
 _ = require("underscore");
 
@@ -25,37 +26,73 @@ _known_tools = {
   pan: function(plot) {
     return new models.PanTool({
       plot: plot,
-      dimensions: ["width", "height"]
+      dimensions: 'both'
     });
   },
   xpan: function(plot) {
     return new models.PanTool({
       plot: plot,
-      dimensions: ["width"]
+      dimensions: 'width'
     });
   },
   ypan: function(plot) {
     return new models.PanTool({
       plot: plot,
-      dimensions: ["height"]
+      dimensions: 'height'
     });
   },
   wheel_zoom: function(plot) {
     return new models.WheelZoomTool({
       plot: plot,
-      dimensions: ["width", "height"]
+      dimensions: 'both'
     });
   },
   xwheel_zoom: function(plot) {
     return new models.WheelZoomTool({
       plot: plot,
-      dimensions: ["width"]
+      dimensions: 'width'
     });
   },
   ywheel_zoom: function(plot) {
     return new models.WheelZoomTool({
       plot: plot,
-      dimensions: ["height"]
+      dimensions: 'height'
+    });
+  },
+  zoom_in: function(plot) {
+    return new models.ZoomInTool({
+      plot: plot,
+      dimensions: 'both'
+    });
+  },
+  xzoom_in: function(plot) {
+    return new models.ZoomInTool({
+      plot: plot,
+      dimensions: 'width'
+    });
+  },
+  yzoom_in: function(plot) {
+    return new models.ZoomInTool({
+      plot: plot,
+      dimensions: 'height'
+    });
+  },
+  zoom_out: function(plot) {
+    return new models.ZoomOutTool({
+      plot: plot,
+      dimensions: 'both'
+    });
+  },
+  xzoom_out: function(plot) {
+    return new models.ZoomOutTool({
+      plot: plot,
+      dimensions: 'width'
+    });
+  },
+  yzoom_out: function(plot) {
+    return new models.ZoomOutTool({
+      plot: plot,
+      dimensions: 'height'
     });
   },
   resize: function(plot) {
@@ -87,13 +124,13 @@ _known_tools = {
   xbox_select: function(plot) {
     return new models.BoxSelectTool({
       plot: plot,
-      dimensions: ['width']
+      dimensions: 'width'
     });
   },
   ybox_select: function(plot) {
     return new models.BoxSelectTool({
       plot: plot,
-      dimensions: ['height']
+      dimensions: 'height'
     });
   },
   poly_select: function(plot) {
@@ -109,19 +146,19 @@ _known_tools = {
   box_zoom: function(plot) {
     return new models.BoxZoomTool({
       plot: plot,
-      dimensions: ['width', 'height']
+      dimensions: 'both'
     });
   },
   xbox_zoom: function(plot) {
     return new models.BoxZoomTool({
       plot: plot,
-      dimensions: ['width']
+      dimensions: 'width'
     });
   },
   ybox_zoom: function(plot) {
     return new models.BoxZoomTool({
       plot: plot,
-      dimensions: ['height']
+      dimensions: 'height'
     });
   },
   hover: function(plot) {
@@ -223,7 +260,8 @@ Figure = (function(superClass) {
     this._process_guides(1, y_axis_type, y_axis_location, y_minor_ticks, y_axis_label);
     this.add_tools.apply(this, this._process_tools(tools));
     this._legend = new models.Legend({
-      plot: this
+      plot: this,
+      items: []
     });
     this.add_renderers(this._legend);
   }
@@ -284,18 +322,18 @@ Figure = (function(superClass) {
     return this._glyph(models.Bezier, "x0,y0,x1,y1,cx0,cy0,cx1,cy1", args);
   };
 
+  Figure.prototype.circle = function() {
+    var args;
+    args = 1 <= arguments.length ? slice.call(arguments, 0) : [];
+    return this._glyph(models.Circle, "x,y", args);
+  };
+
   Figure.prototype.ellipse = function() {
     var args;
     args = 1 <= arguments.length ? slice.call(arguments, 0) : [];
     return this._glyph(models.Ellipse, "x,y,width,height", args);
   };
 
-  Figure.prototype.gear = function() {
-    var args;
-    args = 1 <= arguments.length ? slice.call(arguments, 0) : [];
-    return this._glyph(models.Gear, "x,y,module,teeth", args);
-  };
-
   Figure.prototype.image = function() {
     var args;
     args = 1 <= arguments.length ? slice.call(arguments, 0) : [];
@@ -392,12 +430,6 @@ Figure = (function(superClass) {
     return this._marker(models.Asterisk, args);
   };
 
-  Figure.prototype.circle = function() {
-    var args;
-    args = 1 <= arguments.length ? slice.call(arguments, 0) : [];
-    return this._marker(models.Circle, args);
-  };
-
   Figure.prototype.circle_cross = function() {
     var args;
     args = 1 <= arguments.length ? slice.call(arguments, 0) : [];
@@ -572,7 +604,7 @@ Figure = (function(superClass) {
         fn(param, i);
       }
     }
-    legend = attrs.legend;
+    legend = this._process_legend(attrs.legend, attrs.source);
     delete attrs.legend;
     has_sglyph = _.any(_.keys(attrs), function(key) {
       return key.startsWith("selection_");
@@ -739,19 +771,54 @@ Figure = (function(superClass) {
     return objs;
   };
 
-  Figure.prototype._update_legend = function(legend_name, glyph_renderer) {
-    var j, legends, len, name, ref, renderers;
-    legends = _.clone(this._legend.legends);
-    for (j = 0, len = legends.length; j < len; j++) {
-      ref = legends[j], name = ref[0], renderers = ref[1];
-      if (name === legend_name) {
-        renderers.push(glyph_renderer);
-        this._legend.legends = legends;
-        return;
+  Figure.prototype._process_legend = function(legend, source) {
+    var legend_item_label;
+    legend_item_label = null;
+    if (legend != null) {
+      if (_.isString(legend)) {
+        legend_item_label = {
+          value: legend
+        };
+        if ((source != null) && (source.column_names != null)) {
+          if (indexOf.call(source.column_names, legend) >= 0) {
+            legend_item_label = {
+              field: legend
+            };
+          }
+        }
+      } else {
+        legend_item_label = legend;
       }
     }
-    legends.push([legend_name, [glyph_renderer]]);
-    return this._legend.legends = legends;
+    return legend_item_label;
+  };
+
+  Figure.prototype._update_legend = function(legend_item_label, glyph_renderer) {
+    var added, item, j, len, new_item, ref;
+    added = false;
+    ref = this._legend.items;
+    for (j = 0, len = ref.length; j < len; j++) {
+      item = ref[j];
+      if (_.isEqual(item.label, legend_item_label)) {
+        if (item.label.value != null) {
+          item.renderers.push(glyph_renderer);
+          added = true;
+          break;
+        }
+        if ((item.label.field != null) && glyph_renderer.data_source === item.renderers[0].data_source) {
+          item.renderers.push(glyph_renderer);
+          added = true;
+          break;
+        }
+      }
+    }
+    if (!added) {
+      new_item = new models.LegendItem({
+        label: legend_item_label,
+        renderers: [glyph_renderer]
+      });
+      return this._legend.items.push(new_item);
+    }
   };
 
   return Figure;
