@@ -23,7 +23,7 @@ Message = (function() {
   }
 
   Message.assemble = function(header_json, metadata_json, content_json) {
-    var content, e, error1, header, metadata;
+    var content, e, header, metadata;
     try {
       header = JSON.parse(header_json);
       metadata = JSON.parse(metadata_json);
@@ -55,7 +55,7 @@ Message = (function() {
   };
 
   Message.prototype.send = function(socket) {
-    var content_json, e, error1, header_json, metadata_json;
+    var content_json, e, header_json, metadata_json;
     try {
       header_json = JSON.stringify(this.header);
       metadata_json = JSON.stringify(this.metadata);
@@ -172,7 +172,7 @@ ClientConnection = (function() {
   };
 
   ClientConnection.prototype.connect = function() {
-    var error, error1, versioned_url;
+    var error, versioned_url;
     if (this.closed_permanently) {
       return Promise.reject(new Error("Cannot connect() a closed ClientConnection"));
     }
@@ -250,7 +250,7 @@ ClientConnection = (function() {
   };
 
   ClientConnection.prototype.send = function(message) {
-    var e, error1;
+    var e;
     try {
       if (this.socket === null) {
         throw new Error("not connected so cannot send " + message);
@@ -348,7 +348,7 @@ ClientConnection = (function() {
   };
 
   ClientConnection.prototype._on_message = function(event) {
-    var e, error1;
+    var e;
     try {
       return this._on_message_unchecked(event);
     } catch (error1) {
@@ -575,7 +575,7 @@ pull_session = function(url, session_id) {
   connection = null;
   promise = new Promise(function(resolve, reject) {
     connection = new ClientConnection(url, session_id, function(session) {
-      var e, error1;
+      var e;
       try {
         return resolve(session);
       } catch (error1) {
