@@ -1,4 +1,4 @@
-var Annotation, Legend, LegendView, _, get_text_height, p,
+var Annotation, GlyphRenderer, Legend, LegendView, _, get_text_height, p,
   extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
   hasProp = {}.hasOwnProperty;
 
@@ -6,6 +6,8 @@ _ = require("underscore");
 
 Annotation = require("./annotation");
 
+GlyphRenderer = require("../renderers/glyph_renderer");
+
 p = require("../../core/properties");
 
 get_text_height = require("../../core/util/text").get_text_height;
@@ -22,21 +24,12 @@ LegendView = (function(superClass) {
   };
 
   LegendView.prototype.compute_legend_bbox = function() {
-    var ctx, glyph_height, glyph_width, glyphs, h_range, i, label_height, label_standoff, label_width, legend_height, legend_margin, legend_name, legend_names, legend_padding, legend_spacing, legend_width, len, location, max_label_width, name, ref, v_range, width, x, y;
-    legend_names = (function() {
-      var i, len, ref, ref1, results;
-      ref = this.mget("legends");
-      results = [];
-      for (i = 0, len = ref.length; i < len; i++) {
-        ref1 = ref[i], legend_name = ref1[0], glyphs = ref1[1];
-        results.push(legend_name);
-      }
-      return results;
-    }).call(this);
-    glyph_height = this.mget('glyph_height');
-    glyph_width = this.mget('glyph_width');
-    label_height = this.mget('label_height');
-    label_width = this.mget('label_width');
+    var ctx, glyph_height, glyph_width, h_range, i, label_height, label_standoff, label_width, legend_height, legend_margin, legend_names, legend_padding, legend_spacing, legend_width, len, location, max_label_width, name, ref, v_range, width, x, y;
+    legend_names = this.model.get_legend_names();
+    glyph_height = this.model.glyph_height;
+    glyph_width = this.model.glyph_width;
+    label_height = this.model.label_height;
+    label_width = this.model.label_width;
     this.max_label_height = _.max([get_text_height(this.visuals.label_text.font_value()).height, label_height, glyph_height]);
     ctx = this.plot_view.canvas_view.ctx;
     ctx.save();
@@ -48,11 +41,11 @@ LegendView = (function(superClass) {
     }
     ctx.restore();
     max_label_width = _.max(_.values(this.text_widths));
-    legend_margin = this.mget('legend_margin');
-    legend_padding = this.mget('legend_padding');
-    legend_spacing = this.mget('legend_spacing');
-    label_standoff = this.mget('label_standoff');
-    if (this.mget("orientation") === "vertical") {
+    legend_margin = this.model.margin;
+    legend_padding = this.model.padding;
+    legend_spacing = this.model.spacing;
+    label_standoff = this.model.label_standoff;
+    if (this.model.orientation === "vertical") {
       legend_height = legend_names.length * this.max_label_height + (legend_names.length - 1) * legend_spacing + 2 * legend_padding;
       legend_width = max_label_width + glyph_width + label_standoff + 2 * legend_padding;
     } else {
@@ -64,46 +57,46 @@ LegendView = (function(superClass) {
       }
       legend_height = this.max_label_height + 2 * legend_padding;
     }
-    location = this.mget('location');
-    h_range = this.plot_view.frame.get('h_range');
-    v_range = this.plot_view.frame.get('v_range');
+    location = this.model.location;
+    h_range = this.plot_view.frame.h_range;
+    v_range = this.plot_view.frame.v_range;
     if (_.isString(location)) {
       switch (location) {
         case 'top_left':
-          x = h_range.get('start') + legend_margin;
-          y = v_range.get('end') - legend_margin;
+          x = h_range.start + legend_margin;
+          y = v_range.end - legend_margin;
           break;
         case 'top_center':
-          x = (h_range.get('end') + h_range.get('start')) / 2 - legend_width / 2;
-          y = v_range.get('end') - legend_margin;
+          x = (h_range.end + h_range.start) / 2 - legend_width / 2;
+          y = v_range.end - legend_margin;
           break;
         case 'top_right':
-          x = h_range.get('end') - legend_margin - legend_width;
-          y = v_range.get('end') - legend_margin;
+          x = h_range.end - legend_margin - legend_width;
+          y = v_range.end - legend_margin;
           break;
         case 'right_center':
-          x = h_range.get('end') - legend_margin - legend_width;
-          y = (v_range.get('end') + v_range.get('start')) / 2 + legend_height / 2;
+          x = h_range.end - legend_margin - legend_width;
+          y = (v_range.end + v_range.start) / 2 + legend_height / 2;
           break;
         case 'bottom_right':
-          x = h_range.get('end') - legend_margin - legend_width;
-          y = v_range.get('start') + legend_margin + legend_height;
+          x = h_range.end - legend_margin - legend_width;
+          y = v_range.start + legend_margin + legend_height;
           break;
         case 'bottom_center':
-          x = (h_range.get('end') + h_range.get('start')) / 2 - legend_width / 2;
-          y = v_range.get('start') + legend_margin + legend_height;
+          x = (h_range.end + h_range.start) / 2 - legend_width / 2;
+          y = v_range.start + legend_margin + legend_height;
           break;
         case 'bottom_left':
-          x = h_range.get('start') + legend_margin;
-          y = v_range.get('start') + legend_margin + legend_height;
+          x = h_range.start + legend_margin;
+          y = v_range.start + legend_margin + legend_height;
           break;
         case 'left_center':
-          x = h_range.get('start') + legend_margin;
-          y = (v_range.get('end') + v_range.get('start')) / 2 + legend_height / 2;
+          x = h_range.start + legend_margin;
+          y = (v_range.end + v_range.start) / 2 + legend_height / 2;
           break;
         case 'center':
-          x = (h_range.get('end') + h_range.get('start')) / 2 - legend_width / 2;
-          y = (v_range.get('end') + v_range.get('start')) / 2 + legend_height / 2;
+          x = (h_range.end + h_range.start) / 2 - legend_width / 2;
+          y = (v_range.end + v_range.start) / 2 + legend_height / 2;
       }
     } else if (_.isArray(location) && location.length === 2) {
       x = location[0], y = location[1];
@@ -119,16 +112,20 @@ LegendView = (function(superClass) {
   };
 
   LegendView.prototype.render = function() {
-    var N, bbox, ctx, glyph_height, glyph_width, glyphs, i, idx, j, label_standoff, legend_name, legend_spacing, len, len1, orientation, panel_offset, ref, ref1, renderer, view, x1, x2, xoffset, y1, y2, yoffset;
-    if (this.model.legends.length === 0) {
+    var bbox, ctx;
+    if (this.model.items.length === 0) {
       return;
     }
-    bbox = this.compute_legend_bbox();
-    glyph_height = this.mget('glyph_height');
-    glyph_width = this.mget('glyph_width');
-    orientation = this.mget('orientation');
     ctx = this.plot_view.canvas_view.ctx;
+    bbox = this.compute_legend_bbox();
     ctx.save();
+    this._draw_legend_box(ctx, bbox);
+    this._draw_legend_items(ctx, bbox);
+    return ctx.restore();
+  };
+
+  LegendView.prototype._draw_legend_box = function(ctx, bbox) {
+    var panel_offset;
     if (this.model.panel != null) {
       panel_offset = this._get_panel_offset();
       ctx.translate(panel_offset.x, panel_offset.y);
@@ -139,33 +136,58 @@ LegendView = (function(superClass) {
     ctx.fill();
     if (this.visuals.border_line.doit) {
       this.visuals.border_line.set_value(ctx);
-      ctx.stroke();
+      return ctx.stroke();
     }
-    N = this.mget("legends").length;
-    legend_spacing = this.mget('legend_spacing');
-    label_standoff = this.mget('label_standoff');
-    xoffset = yoffset = this.mget('legend_padding');
-    ref = this.mget("legends");
-    for (idx = i = 0, len = ref.length; i < len; idx = ++i) {
-      ref1 = ref[idx], legend_name = ref1[0], glyphs = ref1[1];
-      x1 = bbox.x + xoffset;
-      y1 = bbox.y + yoffset;
-      x2 = x1 + glyph_width;
-      y2 = y1 + glyph_height;
-      if (orientation === "vertical") {
-        yoffset += this.max_label_height + legend_spacing;
-      } else {
-        xoffset += this.text_widths[legend_name] + glyph_width + label_standoff + legend_spacing;
-      }
-      this.visuals.label_text.set_value(ctx);
-      ctx.fillText(legend_name, x2 + label_standoff, y1 + this.max_label_height / 2.0);
-      for (j = 0, len1 = glyphs.length; j < len1; j++) {
-        renderer = glyphs[j];
-        view = this.plot_view.renderer_views[renderer.id];
-        view.draw_legend(ctx, x1, x2, y1, y2);
+  };
+
+  LegendView.prototype._draw_legend_items = function(ctx, bbox) {
+    var field, glyph_height, glyph_width, i, item, label, label_standoff, labels, legend_spacing, len, r, ref, results, view, x1, x2, xoffset, y1, y2, yoffset;
+    glyph_height = this.model.glyph_height;
+    glyph_width = this.model.glyph_width;
+    legend_spacing = this.model.spacing;
+    label_standoff = this.model.label_standoff;
+    xoffset = yoffset = this.model.padding;
+    ref = this.model.items;
+    results = [];
+    for (i = 0, len = ref.length; i < len; i++) {
+      item = ref[i];
+      labels = item.get_labels_list_from_label_prop();
+      field = item.get_field_from_label_prop();
+      if (labels.length === 0) {
+        continue;
       }
+      results.push((function() {
+        var j, len1, results1;
+        results1 = [];
+        for (j = 0, len1 = labels.length; j < len1; j++) {
+          label = labels[j];
+          x1 = bbox.x + xoffset;
+          y1 = bbox.y + yoffset;
+          x2 = x1 + glyph_width;
+          y2 = y1 + glyph_height;
+          if (this.model.orientation === "vertical") {
+            yoffset += this.max_label_height + legend_spacing;
+          } else {
+            xoffset += this.text_widths[label] + glyph_width + label_standoff + legend_spacing;
+          }
+          this.visuals.label_text.set_value(ctx);
+          ctx.fillText(label, x2 + label_standoff, y1 + this.max_label_height / 2.0);
+          results1.push((function() {
+            var k, len2, ref1, results2;
+            ref1 = item.renderers;
+            results2 = [];
+            for (k = 0, len2 = ref1.length; k < len2; k++) {
+              r = ref1[k];
+              view = this.plot_view.renderer_views[r.id];
+              results2.push(view.draw_legend(ctx, x1, x2, y1, y2, field, label));
+            }
+            return results2;
+          }).call(this));
+        }
+        return results1;
+      }).call(this));
     }
-    return ctx.restore();
+    return results;
   };
 
   LegendView.prototype._get_size = function() {
@@ -205,10 +227,21 @@ Legend = (function(superClass) {
 
   Legend.prototype.type = 'Legend';
 
+  Legend.prototype.get_legend_names = function() {
+    var i, item, labels, legend_names, len, ref;
+    legend_names = [];
+    ref = this.items;
+    for (i = 0, len = ref.length; i < len; i++) {
+      item = ref[i];
+      labels = item.get_labels_list_from_label_prop();
+      legend_names = legend_names.concat(labels);
+    }
+    return legend_names;
+  };
+
   Legend.mixins(['text:label_', 'line:border_', 'fill:background_']);
 
   Legend.define({
-    legends: [p.Array, []],
     orientation: [p.Orientation, 'vertical'],
     location: [p.Any, 'top_right'],
     label_standoff: [p.Number, 5],
@@ -216,9 +249,10 @@ Legend = (function(superClass) {
     glyph_width: [p.Number, 20],
     label_height: [p.Number, 20],
     label_width: [p.Number, 20],
-    legend_margin: [p.Number, 10],
-    legend_padding: [p.Number, 10],
-    legend_spacing: [p.Number, 3]
+    margin: [p.Number, 10],
+    padding: [p.Number, 10],
+    spacing: [p.Number, 3],
+    items: [p.Array, []]
   });
 
   Legend.override({
