@@ -25,8 +25,8 @@ AxisView = (function(superClass) {
 
   AxisView.prototype.initialize = function(options) {
     AxisView.__super__.initialize.call(this, options);
-    this._x_range_name = this.mget('x_range_name');
-    return this._y_range_name = this.mget('y_range_name');
+    this._x_range_name = this.model.x_range_name;
+    return this._y_range_name = this.model.y_range_name;
   };
 
   AxisView.prototype.render = function() {
@@ -57,10 +57,10 @@ AxisView = (function(superClass) {
     if (!this.visuals.axis_line.doit) {
       return;
     }
-    ref = coords = this.mget('rule_coords'), x = ref[0], y = ref[1];
+    ref = coords = this.model.rule_coords, x = ref[0], y = ref[1];
     ref1 = this.plot_view.map_to_screen(x, y, this._x_range_name, this._y_range_name), sx = ref1[0], sy = ref1[1];
-    ref2 = this.mget('normals'), nx = ref2[0], ny = ref2[1];
-    ref3 = this.mget('offsets'), xoff = ref3[0], yoff = ref3[1];
+    ref2 = this.model.normals, nx = ref2[0], ny = ref2[1];
+    ref3 = this.model.offsets, xoff = ref3[0], yoff = ref3[1];
     this.visuals.axis_line.set_value(ctx);
     ctx.beginPath();
     ctx.moveTo(Math.round(sx[0] + nx * xoff), Math.round(sy[0] + ny * yoff));
@@ -75,13 +75,13 @@ AxisView = (function(superClass) {
     if (!this.visuals.major_tick_line.doit) {
       return;
     }
-    coords = this.mget('tick_coords');
+    coords = this.model.tick_coords;
     ref = coords.major, x = ref[0], y = ref[1];
     ref1 = this.plot_view.map_to_screen(x, y, this._x_range_name, this._y_range_name), sx = ref1[0], sy = ref1[1];
-    ref2 = this.mget('normals'), nx = ref2[0], ny = ref2[1];
-    ref3 = this.mget('offsets'), xoff = ref3[0], yoff = ref3[1];
-    tin = this.mget('major_tick_in');
-    tout = this.mget('major_tick_out');
+    ref2 = this.model.normals, nx = ref2[0], ny = ref2[1];
+    ref3 = this.model.offsets, xoff = ref3[0], yoff = ref3[1];
+    tin = this.model.major_tick_in;
+    tout = this.model.major_tick_out;
     this.visuals.major_tick_line.set_value(ctx);
     results = [];
     for (i = k = 0, ref4 = sx.length; 0 <= ref4 ? k < ref4 : k > ref4; i = 0 <= ref4 ? ++k : --k) {
@@ -98,13 +98,13 @@ AxisView = (function(superClass) {
     if (!this.visuals.minor_tick_line.doit) {
       return;
     }
-    coords = this.mget('tick_coords');
+    coords = this.model.tick_coords;
     ref = coords.minor, x = ref[0], y = ref[1];
     ref1 = this.plot_view.map_to_screen(x, y, this._x_range_name, this._y_range_name), sx = ref1[0], sy = ref1[1];
-    ref2 = this.mget('normals'), nx = ref2[0], ny = ref2[1];
-    ref3 = this.mget('offsets'), xoff = ref3[0], yoff = ref3[1];
-    tin = this.mget('minor_tick_in');
-    tout = this.mget('minor_tick_out');
+    ref2 = this.model.normals, nx = ref2[0], ny = ref2[1];
+    ref3 = this.model.offsets, xoff = ref3[0], yoff = ref3[1];
+    tin = this.model.minor_tick_in;
+    tout = this.model.minor_tick_out;
     this.visuals.minor_tick_line.set_value(ctx);
     results = [];
     for (i = k = 0, ref4 = sx.length; 0 <= ref4 ? k < ref4 : k > ref4; i = 0 <= ref4 ? ++k : --k) {
@@ -118,21 +118,21 @@ AxisView = (function(superClass) {
 
   AxisView.prototype._draw_major_labels = function(ctx) {
     var angle, coords, dim, i, k, labels, nx, ny, orient, ref, ref1, ref2, ref3, ref4, results, side, standoff, sx, sy, x, xoff, y, yoff;
-    coords = this.mget('tick_coords');
+    coords = this.model.tick_coords;
     ref = coords.major, x = ref[0], y = ref[1];
     ref1 = this.plot_view.map_to_screen(x, y, this._x_range_name, this._y_range_name), sx = ref1[0], sy = ref1[1];
-    ref2 = this.mget('normals'), nx = ref2[0], ny = ref2[1];
-    ref3 = this.mget('offsets'), xoff = ref3[0], yoff = ref3[1];
-    dim = this.mget('dimension');
-    side = this.mget('panel_side');
-    orient = this.mget('major_label_orientation');
+    ref2 = this.model.normals, nx = ref2[0], ny = ref2[1];
+    ref3 = this.model.offsets, xoff = ref3[0], yoff = ref3[1];
+    dim = this.model.dimension;
+    side = this.model.panel_side;
+    orient = this.model.major_label_orientation;
     if (_.isString(orient)) {
       angle = this.model.panel.get_label_angle_heuristic(orient);
     } else {
       angle = -orient;
     }
-    standoff = this._tick_extent() + this.mget('major_label_standoff');
-    labels = this.mget('formatter').doFormat(coords.major[dim]);
+    standoff = this._tick_extent() + this.model.major_label_standoff;
+    labels = this.model.formatter.doFormat(coords.major[dim]);
     this.visuals.major_label_text.set_value(ctx);
     this.model.panel.apply_label_text_heuristics(ctx, orient);
     results = [];
@@ -152,18 +152,18 @@ AxisView = (function(superClass) {
 
   AxisView.prototype._draw_axis_label = function(ctx) {
     var angle, label, nx, ny, orient, ref, ref1, ref2, ref3, side, standoff, sx, sy, x, xoff, y, yoff;
-    label = this.mget('axis_label');
+    label = this.model.axis_label;
     if (label == null) {
       return;
     }
-    ref = this.mget('rule_coords'), x = ref[0], y = ref[1];
+    ref = this.model.rule_coords, x = ref[0], y = ref[1];
     ref1 = this.plot_view.map_to_screen(x, y, this._x_range_name, this._y_range_name), sx = ref1[0], sy = ref1[1];
-    ref2 = this.mget('normals'), nx = ref2[0], ny = ref2[1];
-    ref3 = this.mget('offsets'), xoff = ref3[0], yoff = ref3[1];
-    side = this.mget('panel_side');
+    ref2 = this.model.normals, nx = ref2[0], ny = ref2[1];
+    ref3 = this.model.offsets, xoff = ref3[0], yoff = ref3[1];
+    side = this.model.panel_side;
     orient = 'parallel';
     angle = this.model.panel.get_label_angle_heuristic(orient);
-    standoff = this._tick_extent() + this._tick_label_extent() + this.mget('axis_label_standoff');
+    standoff = this._tick_extent() + this._tick_label_extent() + this.model.axis_label_standoff;
     sx = (sx[0] + sx[sx.length - 1]) / 2;
     sy = (sy[0] + sy[sy.length - 1]) / 2;
     this.visuals.axis_label_text.set_value(ctx);
@@ -185,18 +185,18 @@ AxisView = (function(superClass) {
   };
 
   AxisView.prototype._tick_extent = function() {
-    return this.mget('major_tick_out');
+    return this.model.major_tick_out;
   };
 
   AxisView.prototype._tick_label_extent = function() {
     var angle, c, coords, ctx, dim, extent, h, hfactor, hscale, i, k, labels, orient, ref, s, side, val, w, wfactor;
     extent = 0;
     ctx = this.plot_view.canvas_view.ctx;
-    dim = this.mget('dimension');
-    coords = this.mget('tick_coords').major;
-    side = this.mget('panel_side');
-    orient = this.mget('major_label_orientation');
-    labels = this.mget('formatter').doFormat(coords[dim]);
+    dim = this.model.dimension;
+    coords = this.model.tick_coords.major;
+    side = this.model.panel_side;
+    orient = this.model.major_label_orientation;
+    labels = this.model.formatter.doFormat(coords[dim]);
     this.visuals.major_label_text.set_value(ctx);
     if (_.isString(orient)) {
       hscale = 1;
@@ -227,7 +227,7 @@ AxisView = (function(superClass) {
       }
     }
     if (extent > 0) {
-      extent += this.mget('major_label_standoff');
+      extent += this.model.major_label_standoff;
     }
     return extent;
   };
@@ -235,8 +235,8 @@ AxisView = (function(superClass) {
   AxisView.prototype._axis_label_extent = function() {
     var angle, axis_label, c, ctx, extent, h, orient, s, side, w;
     extent = 0;
-    side = this.mget('panel_side');
-    axis_label = this.mget('axis_label');
+    side = this.model.panel_side;
+    axis_label = this.model.axis_label;
     orient = 'parallel';
     ctx = this.plot_view.canvas_view.ctx;
     this.visuals.axis_label_text.set_value(ctx);
@@ -244,7 +244,7 @@ AxisView = (function(superClass) {
     c = Math.cos(angle);
     s = Math.sin(angle);
     if (axis_label) {
-      extent += this.mget('axis_label_standoff');
+      extent += this.model.axis_label_standoff;
       this.visuals.axis_label_text.set_value(ctx);
       w = ctx.measureText(axis_label).width * 1.1;
       h = ctx.measureText(axis_label).ascent * 0.9;
@@ -309,60 +309,76 @@ Axis = (function(superClass) {
     Axis.__super__.initialize.call(this, attrs, options);
     this.define_computed_property('computed_bounds', this._computed_bounds, false);
     this.add_dependencies('computed_bounds', this, ['bounds']);
-    this.add_dependencies('computed_bounds', this.get('plot'), ['x_range', 'y_range']);
-    this.define_computed_property('rule_coords', this._rule_coords, false);
-    this.add_dependencies('rule_coords', this, ['computed_bounds', 'side']);
-    this.define_computed_property('tick_coords', this._tick_coords, false);
-    this.add_dependencies('tick_coords', this, ['computed_bounds', 'panel_side']);
-    this.define_computed_property('ranges', this._ranges, true);
-    this.define_computed_property('normals', (function() {
-      return this.panel._normals;
-    }), true);
-    this.define_computed_property('dimension', (function() {
-      return this.panel._dim;
-    }), true);
-    return this.define_computed_property('offsets', this._offsets, true);
+    return this.add_dependencies('computed_bounds', this.plot, ['x_range', 'y_range']);
   };
 
+  Axis.getters({
+    computed_bounds: function() {
+      return this._get_computed('computed_bounds');
+    },
+    rule_coords: function() {
+      return this._rule_coords();
+    },
+    tick_coords: function() {
+      return this._tick_coords();
+    },
+    ranges: function() {
+      return this._ranges();
+    },
+    normals: function() {
+      return this.panel._normals;
+    },
+    dimension: function() {
+      return this.panel._dim;
+    },
+    offsets: function() {
+      return this._offsets();
+    }
+  });
+
   Axis.prototype.add_panel = function(side) {
     this.panel = new SidePanel.Model({
       side: side
     });
     this.panel.attach_document(this.document);
-    return this.set('panel_side', side);
+    return this.panel_side = side;
   };
 
   Axis.prototype._offsets = function() {
     var frame, ref, side, xoff, yoff;
-    side = this.get('panel_side');
+    side = this.panel_side;
     ref = [0, 0], xoff = ref[0], yoff = ref[1];
-    frame = this.plot.plot_canvas.get('frame');
-    if (side === "below") {
-      yoff = Math.abs(this.panel.get("top") - frame.get("bottom"));
-    } else if (side === "above") {
-      yoff = Math.abs(this.panel.get("bottom") - frame.get("top"));
-    } else if (side === "right") {
-      xoff = Math.abs(this.panel.get("left") - frame.get("right"));
-    } else if (side === "left") {
-      xoff = Math.abs(this.panel.get("right") - frame.get("left"));
+    frame = this.plot.plot_canvas.frame;
+    switch (side) {
+      case "below":
+        yoff = Math.abs(this.panel.top - frame.bottom);
+        break;
+      case "above":
+        yoff = Math.abs(this.panel.bottom - frame.top);
+        break;
+      case "right":
+        xoff = Math.abs(this.panel.left - frame.right);
+        break;
+      case "left":
+        xoff = Math.abs(this.panel.right - frame.left);
     }
     return [xoff, yoff];
   };
 
   Axis.prototype._ranges = function() {
     var frame, i, j, ranges;
-    i = this.get('dimension');
+    i = this.dimension;
     j = (i + 1) % 2;
-    frame = this.plot.plot_canvas.get('frame');
-    ranges = [frame.get('x_ranges')[this.get('x_range_name')], frame.get('y_ranges')[this.get('y_range_name')]];
+    frame = this.plot.plot_canvas.frame;
+    ranges = [frame.x_ranges[this.x_range_name], frame.y_ranges[this.y_range_name]];
     return [ranges[i], ranges[j]];
   };
 
   Axis.prototype._computed_bounds = function() {
     var cross_range, end, range, range_bounds, ref, ref1, start, user_bounds;
-    ref = this.get('ranges'), range = ref[0], cross_range = ref[1];
-    user_bounds = (ref1 = this.get('bounds')) != null ? ref1 : 'auto';
-    range_bounds = [range.get('min'), range.get('max')];
+    ref = this.ranges, range = ref[0], cross_range = ref[1];
+    user_bounds = (ref1 = this.bounds) != null ? ref1 : 'auto';
+    range_bounds = [range.min, range.max];
     if (user_bounds === 'auto') {
       return range_bounds;
     }
@@ -382,18 +398,18 @@ Axis = (function(superClass) {
 
   Axis.prototype._rule_coords = function() {
     var coords, cross_range, end, i, j, loc, range, ref, ref1, start, xs, ys;
-    i = this.get('dimension');
+    i = this.dimension;
     j = (i + 1) % 2;
-    ref = this.get('ranges'), range = ref[0], cross_range = ref[1];
-    ref1 = this.get('computed_bounds'), start = ref1[0], end = ref1[1];
+    ref = this.ranges, range = ref[0], cross_range = ref[1];
+    ref1 = this.computed_bounds, start = ref1[0], end = ref1[1];
     xs = new Array(2);
     ys = new Array(2);
     coords = [xs, ys];
     loc = this._get_loc(cross_range);
-    coords[i][0] = Math.max(start, range.get('min'));
-    coords[i][1] = Math.min(end, range.get('max'));
+    coords[i][0] = Math.max(start, range.min);
+    coords[i][1] = Math.min(end, range.max);
     if (coords[i][0] > coords[i][1]) {
-      coords[i][0] = coords[i][1] = NaN;
+      coords[i][0] = coords[i][1] = 0/0;
     }
     coords[j][0] = loc;
     coords[j][1] = loc;
@@ -402,11 +418,11 @@ Axis = (function(superClass) {
 
   Axis.prototype._tick_coords = function() {
     var coords, cross_range, end, i, ii, j, k, l, loc, m, majors, minor_coords, minor_xs, minor_ys, minors, range, range_max, range_min, ref, ref1, ref2, ref3, ref4, ref5, start, ticks, xs, ys;
-    i = this.get('dimension');
+    i = this.dimension;
     j = (i + 1) % 2;
-    ref = this.get('ranges'), range = ref[0], cross_range = ref[1];
-    ref1 = this.get('computed_bounds'), start = ref1[0], end = ref1[1];
-    ticks = this.get('ticker').get_ticks(start, end, range, {});
+    ref = this.ranges, range = ref[0], cross_range = ref[1];
+    ref1 = this.computed_bounds, start = ref1[0], end = ref1[1];
+    ticks = this.ticker.get_ticks(start, end, range, {});
     majors = ticks.major;
     minors = ticks.minor;
     loc = this._get_loc(cross_range);
@@ -422,7 +438,7 @@ Axis = (function(superClass) {
         coords[j].push(loc);
       }
     } else {
-      ref3 = [range.get('min'), range.get('max')], range_min = ref3[0], range_max = ref3[1];
+      ref3 = [range.min, range.max], range_min = ref3[0], range_max = ref3[1];
       for (ii = l = 0, ref4 = majors.length; 0 <= ref4 ? l < ref4 : l > ref4; ii = 0 <= ref4 ? ++l : --l) {
         if (majors[ii] < range_min || majors[ii] > range_max) {
           continue;
@@ -445,16 +461,18 @@ Axis = (function(superClass) {
   };
 
   Axis.prototype._get_loc = function(cross_range) {
-    var cend, cstart, loc, side;
-    cstart = cross_range.get('start');
-    cend = cross_range.get('end');
-    side = this.get('panel_side');
-    if (side === 'left' || side === 'below') {
-      loc = 'start';
-    } else if (side === 'right' || side === 'above') {
-      loc = 'end';
+    var cend, cstart, side;
+    cstart = cross_range.start;
+    cend = cross_range.end;
+    side = this.panel_side;
+    switch (side) {
+      case 'left':
+      case 'below':
+        return cross_range.start;
+      case 'right':
+      case 'above':
+        return cross_range.end;
     }
-    return cross_range.get(loc);
   };
 
   return Axis;
