@@ -1,4 +1,4 @@
-var DEFAULT_DATETIME_FORMATS, DatetimeTickFormatter, SPrintf, TickFormatter, _, _array, _strftime, _us, logger, p, tz,
+var DatetimeTickFormatter, SPrintf, TickFormatter, _, _array, _strftime, _us, logger, p, tz,
   extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
   hasProp = {}.hasOwnProperty;
 
@@ -38,19 +38,6 @@ _strftime = function(t, format) {
   }
 };
 
-DEFAULT_DATETIME_FORMATS = {
-  'microseconds': ['%fus'],
-  'milliseconds': ['%3Nms', '%S.%3Ns'],
-  'seconds': ['%Ss'],
-  'minsec': [':%M:%S'],
-  'minutes': [':%M', '%Mm'],
-  'hourmin': ['%H:%M'],
-  'hours': ['%Hh', '%H:%M'],
-  'days': ['%m/%d', '%a%d'],
-  'months': ['%m/%Y', '%b%y'],
-  'years': ['%Y']
-};
-
 DatetimeTickFormatter = (function(superClass) {
   extend(DatetimeTickFormatter, superClass);
 
@@ -61,7 +48,16 @@ DatetimeTickFormatter = (function(superClass) {
   DatetimeTickFormatter.prototype.type = 'DatetimeTickFormatter';
 
   DatetimeTickFormatter.define({
-    formats: [p.Any, DEFAULT_DATETIME_FORMATS]
+    microseconds: [p.Array, ['%fus']],
+    milliseconds: [p.Array, ['%3Nms', '%S.%3Ns']],
+    seconds: [p.Array, ['%Ss']],
+    minsec: [p.Array, [':%M:%S']],
+    minutes: [p.Array, [':%M', '%Mm']],
+    hourmin: [p.Array, ['%H:%M']],
+    hours: [p.Array, ['%Hh', '%H:%M']],
+    days: [p.Array, ['%m/%d', '%a%d']],
+    months: [p.Array, ['%m/%Y', '%b%y']],
+    years: [p.Array, ['%Y']]
   });
 
   DatetimeTickFormatter.prototype.format_order = ['microseconds', 'milliseconds', 'seconds', 'minsec', 'minutes', 'hourmin', 'hours', 'days', 'months', 'years'];
@@ -74,65 +70,73 @@ DatetimeTickFormatter = (function(superClass) {
   };
 
   DatetimeTickFormatter.prototype._update_width_formats = function() {
-    var fmt_name, fmt_string, fmt_strings, now, ref, results, sizes, sorted;
+    var _widths, now;
     now = tz(new Date());
-    this._width_formats = {};
-    ref = this.formats;
-    results = [];
-    for (fmt_name in ref) {
-      fmt_strings = ref[fmt_name];
+    _widths = function(fmt_strings) {
+      var fmt_string, sizes, sorted;
       sizes = (function() {
-        var j, len, results1;
-        results1 = [];
+        var j, len, results;
+        results = [];
         for (j = 0, len = fmt_strings.length; j < len; j++) {
           fmt_string = fmt_strings[j];
-          results1.push(_strftime(now, fmt_string).length);
+          results.push(_strftime(now, fmt_string).length);
         }
-        return results1;
+        return results;
       })();
       sorted = _.sortBy(_.zip(sizes, fmt_strings), function(arg) {
         var fmt, size;
         size = arg[0], fmt = arg[1];
         return size;
       });
-      results.push(this._width_formats[fmt_name] = _.zip.apply(_, sorted));
-    }
-    return results;
+      return _.zip.apply(_, sorted);
+    };
+    return this._width_formats = {
+      microseconds: _widths(this.microseconds),
+      milliseconds: _widths(this.milliseconds),
+      seconds: _widths(this.seconds),
+      minsec: _widths(this.minsec),
+      minutes: _widths(this.minutes),
+      hourmin: _widths(this.hourmin),
+      hours: _widths(this.hours),
+      days: _widths(this.days),
+      months: _widths(this.months),
+      years: _widths(this.years)
+    };
   };
 
   DatetimeTickFormatter.prototype._get_resolution_str = function(resolution_secs, span_secs) {
-    var adjusted_resolution_secs, str;
-    adjusted_resolution_secs = resolution_secs * 1.1;
-    if (adjusted_resolution_secs < 1e-3) {
-      str = "microseconds";
-    } else if (adjusted_resolution_secs < 1.0) {
-      str = "milliseconds";
-    } else if (adjusted_resolution_secs < 60) {
-      if (span_secs >= 60) {
-        str = "minsec";
-      } else {
-        str = "seconds";
-      }
-    } else if (adjusted_resolution_secs < 3600) {
-      if (span_secs >= 3600) {
-        str = "hourmin";
-      } else {
-        str = "minutes";
-      }
-    } else if (adjusted_resolution_secs < 24 * 3600) {
-      str = "hours";
-    } else if (adjusted_resolution_secs < 31 * 24 * 3600) {
-      str = "days";
-    } else if (adjusted_resolution_secs < 365 * 24 * 3600) {
-      str = "months";
-    } else {
-      str = "years";
+    var adjusted_secs;
+    adjusted_secs = resolution_secs * 1.1;
+    switch (false) {
+      case !(adjusted_secs < 1e-3):
+        return "microseconds";
+      case !(adjusted_secs < 1.0):
+        return "milliseconds";
+      case !(adjusted_secs < 60):
+        if (span_secs >= 60) {
+          return "minsec";
+        } else {
+          return "seconds";
+        }
+      case !(adjusted_secs < 3600):
+        if (span_secs >= 3600) {
+          return "hourmin";
+        } else {
+          return "minutes";
+        }
+      case !(adjusted_secs < 24 * 3600):
+        return "hours";
+      case !(adjusted_secs < 31 * 24 * 3600):
+        return "days";
+      case !(adjusted_secs < 365 * 24 * 3600):
+        return "months";
+      default:
+        return "years";
     }
-    return str;
   };
 
   DatetimeTickFormatter.prototype.doFormat = function(ticks, num_labels, char_width, fill_ratio, ticker) {
-    var error, error1, fmt, format, formats, good_formats, hybrid_handled, i, j, k, l, labels, len, len1, next_format, next_ndx, r, ref, ref1, ref2, resol, resol_ndx, s, span, ss, t, time_tuple_ndx_for_resol, tm, widths;
+    var error, fmt, format, formats, good_formats, hybrid_handled, i, j, k, l, labels, len, len1, next_format, next_ndx, r, ref, ref1, ref2, resol, resol_ndx, s, span, ss, t, time_tuple_ndx_for_resol, tm, widths;
     if (num_labels == null) {
       num_labels = null;
     }
