@@ -68,8 +68,8 @@ QuadraticView = (function(superClass) {
     }
   };
 
-  QuadraticView.prototype.draw_legend = function(ctx, x0, x1, y0, y1) {
-    return this._generic_line_legend(ctx, x0, x1, y0, y1);
+  QuadraticView.prototype.draw_legend_for_index = function(ctx, x0, x1, y0, y1, index) {
+    return this._generic_line_legend(ctx, x0, x1, y0, y1, index);
   };
 
   return QuadraticView;
