@@ -54,8 +54,8 @@ SegmentView = (function(superClass) {
     }
   };
 
-  SegmentView.prototype.draw_legend = function(ctx, x0, x1, y0, y1) {
-    return this._generic_line_legend(ctx, x0, x1, y0, y1);
+  SegmentView.prototype.draw_legend_for_index = function(ctx, x0, x1, y0, y1, index) {
+    return this._generic_line_legend(ctx, x0, x1, y0, y1, index);
   };
 
   return SegmentView;
