@@ -17,9 +17,9 @@ CategoricalTicker = (function(superClass) {
     var desired_n_ticks, factors, i, ii, j, majors, ref;
     desired_n_ticks = arg.desired_n_ticks;
     majors = [];
-    factors = range.get("factors");
+    factors = range.factors;
     for (i = j = 0, ref = factors.length; 0 <= ref ? j < ref : j > ref; i = 0 <= ref ? ++j : --j) {
-      ii = i + range.get('offset');
+      ii = i + range.offset;
       if ((ii + 1) > start && (ii + 1) < end) {
         majors.push(factors[i]);
       }
