@@ -16,7 +16,7 @@ HelpToolView = (function(superClass) {
   }
 
   HelpToolView.prototype["do"] = function() {
-    return window.open(this.mget('redirect'));
+    return window.open(this.model.redirect);
   };
 
   return HelpToolView;
@@ -43,12 +43,11 @@ HelpTool = (function(superClass) {
     redirect: [p.String, 'http://bokeh.pydata.org/en/latest/docs/user_guide/tools.html']
   });
 
-  HelpTool.prototype.initialize = function(attrs, options) {
-    HelpTool.__super__.initialize.call(this, attrs, options);
-    return this.override_computed_property('tooltip', function() {
-      return this.get('help_tooltip');
-    });
-  };
+  HelpTool.getters({
+    tooltip: function() {
+      return this.help_tooltip;
+    }
+  });
 
   return HelpTool;
 
