@@ -44,8 +44,8 @@ ResizeToolView = (function(superClass) {
     if (this.active) {
       canvas = this.plot_view.canvas;
       frame = this.plot_view.frame;
-      left = canvas.vx_to_sx(frame.get('h_range').get('end') - 40);
-      top = canvas.vy_to_sy(frame.get('v_range').get('start') + 40);
+      left = canvas.vx_to_sx(frame.h_range.end - 40);
+      top = canvas.vy_to_sy(frame.v_range.start + 40);
       this.$el.attr('style', "position:absolute; top:" + top + "px; left:" + left + "px;");
       this.$el.show();
     } else {
@@ -57,8 +57,8 @@ ResizeToolView = (function(superClass) {
   ResizeToolView.prototype._pan_start = function(e) {
     var canvas;
     canvas = this.plot_view.canvas;
-    this.ch = canvas.get('height');
-    this.cw = canvas.get('width');
+    this.ch = canvas.height;
+    this.cw = canvas.width;
     this.plot_view.interactive_timestamp = Date.now();
     return null;
   };
@@ -72,16 +72,20 @@ ResizeToolView = (function(superClass) {
   ResizeToolView.prototype._pan_end = function(e) {
     return this.plot_view.push_state("resize", {
       dimensions: {
-        width: this.plot_view.canvas.get("width"),
-        height: this.plot_view.canvas.get("height")
+        width: this.plot_view.canvas.width,
+        height: this.plot_view.canvas.height
       }
     });
   };
 
   ResizeToolView.prototype._update = function(dx, dy) {
-    this.plot_view.pause();
-    this.plot_view.canvas_view.set_dims([this.cw + dx, this.ch + dy]);
-    this.plot_view.unpause();
+    var new_height, new_width;
+    new_width = this.cw + dx;
+    new_height = this.cw + dy;
+    if (new_width < 100 || new_height < 100) {
+      return;
+    }
+    this.plot_view.update_dimensions(new_width, new_height);
   };
 
   return ResizeToolView;
