@@ -25,24 +25,30 @@ TapToolView = (function(superClass) {
   };
 
   TapToolView.prototype._select = function(vx, vy, final, append) {
-    var callback, cb_data, did_hit, ds, fn, geometry, i, len, r, ref, sm;
+    var callback, cb_data, did_hit, ds, geometry, i, len, r, ref, sm, view;
     geometry = {
       type: 'point',
       vx: vx,
       vy: vy
     };
-    callback = this.mget("callback");
+    callback = this.model.callback;
     this._save_geometry(geometry, final, append);
     cb_data = {
-      geometries: this.plot_model.plot.tool_events.get('geometries')
+      geometries: this.plot_model.plot.tool_events.geometries
     };
-    ref = this.mget('computed_renderers');
+    ref = this.model.computed_renderers;
     for (i = 0, len = ref.length; i < len; i++) {
       r = ref[i];
-      ds = r.get('data_source');
-      sm = ds.get('selection_manager');
-      fn = this.model.behavior === "select" ? sm.select : sm.inspect;
-      did_hit = fn.bind(sm)(this, this.plot_view.renderer_views[r.id], geometry, final, append);
+      ds = r.data_source;
+      sm = ds.selection_manager;
+      view = this.plot_view.renderer_views[r.id];
+      if (this.model.behavior === "select") {
+        did_hit = sm.select(this, view, geometry, final, append);
+      } else {
+        did_hit = sm.inspect(this, view, geometry, {
+          geometry: geometry
+        });
+      }
       if (did_hit && (callback != null)) {
         if (_.isFunction(callback)) {
           callback(ds, cb_data);
