@@ -13,10 +13,6 @@ Transform = (function(superClass) {
     return Transform.__super__.constructor.apply(this, arguments);
   }
 
-  Transform.prototype.defaults = function() {
-    return _.extend({}, Transform.__super__.defaults.call(this));
-  };
-
   return Transform;
 
 })(Model);
