@@ -49,9 +49,9 @@ StringFormatter = (function(superClass) {
   StringFormatter.prototype.doFormat = function(row, cell, value, columnDef, dataContext) {
     var font_style, text, text_align, text_color;
     text = StringFormatter.__super__.doFormat.call(this, row, cell, value, columnDef, dataContext);
-    font_style = this.get("font_style");
-    text_align = this.get("text_align");
-    text_color = this.get("text_color");
+    font_style = this.font_style;
+    text_align = this.text_align;
+    text_color = this.text_color;
     if ((font_style != null) || (text_align != null) || (text_color != null)) {
       text = $("<span>" + text + "</span>");
       switch (font_style) {
@@ -93,10 +93,10 @@ NumberFormatter = (function(superClass) {
 
   NumberFormatter.prototype.doFormat = function(row, cell, value, columnDef, dataContext) {
     var format, language, rounding;
-    format = this.get("format");
-    language = this.get("language");
+    format = this.format;
+    language = this.language;
     rounding = (function() {
-      switch (this.get("rounding")) {
+      switch (this.rounding) {
         case "round":
         case "nearest":
           return Math.round;
@@ -131,7 +131,7 @@ BooleanFormatter = (function(superClass) {
 
   BooleanFormatter.prototype.doFormat = function(row, cell, value, columnDef, dataContext) {
     if (!!value) {
-      return $('<i>').addClass(this.get("icon")).html();
+      return $('<i>').addClass(this.icon).html();
     } else {
       return "";
     }
@@ -156,7 +156,7 @@ DateFormatter = (function(superClass) {
 
   DateFormatter.prototype.getFormat = function() {
     var format, name;
-    format = this.get("format");
+    format = this.format;
     name = (function() {
       switch (format) {
         case "ATOM":
@@ -218,7 +218,7 @@ HTMLTemplateFormatter = (function(superClass) {
 
   HTMLTemplateFormatter.prototype.doFormat = function(row, cell, value, columnDef, dataContext) {
     var compiled_template, template;
-    template = this.get("template");
+    template = this.template;
     if (value === null) {
       return "";
     } else {
