@@ -38,17 +38,17 @@ SliderView = (function(superClass) {
     html = this.template(this.model.attributes);
     this.$el.html(html);
     this.callbackWrapper = null;
-    if (this.mget('callback_policy') === 'continuous') {
+    if (this.model.callback_policy === 'continuous') {
       this.callbackWrapper = function() {
         var ref;
-        return (ref = this.mget('callback')) != null ? ref.execute(this.model) : void 0;
+        return (ref = this.model.callback) != null ? ref.execute(this.model) : void 0;
       };
     }
-    if (this.mget('callback_policy') === 'throttle' && this.mget('callback')) {
+    if (this.model.callback_policy === 'throttle' && this.model.callback) {
       this.callbackWrapper = _.throttle(function() {
         var ref;
-        return (ref = this.mget('callback')) != null ? ref.execute(this.model) : void 0;
-      }, this.mget('callback_throttle'));
+        return (ref = this.model.callback) != null ? ref.execute(this.model) : void 0;
+      }, this.model.callback_throttle);
     }
     return this.render();
   };
@@ -56,14 +56,14 @@ SliderView = (function(superClass) {
   SliderView.prototype.render = function() {
     var max, min, opts, step;
     SliderView.__super__.render.call(this);
-    max = this.mget('end');
-    min = this.mget('start');
-    step = this.mget('step') || ((max - min) / 50);
+    max = this.model.end;
+    min = this.model.start;
+    step = this.model.step || ((max - min) / 50);
     logger.debug("slider render: min, max, step = (" + min + ", " + max + ", " + step + ")");
     opts = {
-      orientation: this.mget('orientation'),
+      orientation: this.model.orientation,
       animate: "fast",
-      value: this.mget('value'),
+      value: this.model.value,
       min: min,
       max: max,
       step: step,
@@ -71,15 +71,17 @@ SliderView = (function(superClass) {
       slide: this.slide
     };
     this.$el.find('.slider').slider(opts);
-    this.$("#" + (this.mget('id'))).val(this.$('.slider').slider('value'));
-    this.$el.find('.bk-slider-parent').height(this.mget('height'));
+    if (this.model.title != null) {
+      this.$("#" + this.model.id).val(this.$('.slider').slider('value'));
+    }
+    this.$el.find('.bk-slider-parent').height(this.model.height);
     return this;
   };
 
   SliderView.prototype.slidestop = function(event, ui) {
     var ref;
-    if (this.mget('callback_policy') === 'mouseup' || this.mget('callback_policy') === 'throttle') {
-      return (ref = this.mget('callback')) != null ? ref.execute(this.model) : void 0;
+    if (this.model.callback_policy === 'mouseup' || this.model.callback_policy === 'throttle') {
+      return (ref = this.model.callback) != null ? ref.execute(this.model) : void 0;
     }
   };
 
@@ -87,8 +89,10 @@ SliderView = (function(superClass) {
     var value;
     value = ui.value;
     logger.debug("slide value = " + value);
-    this.$("#" + (this.mget('id'))).val(ui.value);
-    this.mset('value', value);
+    if (this.model.title != null) {
+      this.$("#" + this.model.id).val(ui.value);
+    }
+    this.model.value = value;
     if (this.callbackWrapper) {
       return this.callbackWrapper();
     }
