@@ -13,7 +13,7 @@ from bokeh.util.future import with_metaclass
 def large_plot(n):
     from bokeh.models import (
         Plot, LinearAxis, Grid, GlyphRenderer,
-        ColumnDataSource, DataRange1d, PanTool, WheelZoomTool, BoxZoomTool,
+        ColumnDataSource, DataRange1d, PanTool, ZoomInTool, ZoomOutTool, WheelZoomTool, BoxZoomTool,
         BoxSelectTool, ResizeTool, SaveTool, ResetTool
     )
     from bokeh.models.layouts import VBox
@@ -36,13 +36,15 @@ def large_plot(n):
         renderer = GlyphRenderer(data_source=source, glyph=glyph)
         plot.renderers.append(renderer)
         pan = PanTool()
+        zoom_in = ZoomInTool()
+        zoom_out = ZoomOutTool()
         wheel_zoom = WheelZoomTool()
         box_zoom = BoxZoomTool()
         box_select = BoxSelectTool()
         resize = ResizeTool()
         save = SaveTool()
         reset = ResetTool()
-        tools = [pan, wheel_zoom, box_zoom, box_select, resize, save, reset]
+        tools = [pan, zoom_in, zoom_out, wheel_zoom, box_zoom, box_select, resize, save, reset]
         plot.add_tools(*tools)
         vbox.children.append(plot)
         objects |= set([
