@@ -1,9 +1,9 @@
 from os.path import dirname, join
 
 from bokeh.core.properties import List, Float, Seq, Color, Int
-from bokeh.models import ColumnDataSource
+from bokeh.models import DataSource
 
-class WaterfallSource(ColumnDataSource):
+class WaterfallSource(DataSource):
 
     __implementation__ = open(join(dirname(__file__), "waterfall.coffee")).read()
 
@@ -16,3 +16,6 @@ class WaterfallSource(ColumnDataSource):
     gram_length = Int()
 
     tile_width = Int()
+
+    @property
+    def column_names(self): return ['x', 'image']
