@@ -1,7 +1,5 @@
 import numpy as np
 
-from bokeh.palettes import Spectral6
-
 
 def process_data():
     from bokeh.sampledata.gapminder import fertility, life_expectancy, population, regions
@@ -15,6 +13,7 @@ def process_data():
     life_expectancy = life_expectancy.rename(columns=rename_dict)
     population = population.rename(columns=rename_dict)
     regions = regions.rename(columns=rename_dict)
+    regions_list = list(regions.Group.unique())
 
     # Turn population into bubble sizes. Use min_size and factor to tweak.
     scale_factor = 200
@@ -22,12 +21,4 @@ def process_data():
     min_size = 3
     population_size = population_size.where(population_size >= min_size).fillna(min_size)
 
-    # Use pandas categories and categorize & color the regions
-    regions.Group = regions.Group.astype('category')
-    regions_list = list(regions.Group.cat.categories)
-
-    def get_color(r):
-        return Spectral6[regions_list.index(r.Group)]
-    regions['region_color'] = regions.apply(get_color, axis=1)
-
     return fertility, life_expectancy, population_size, regions, years, regions_list
